@@ -15,6 +15,10 @@
  *                                                                         *
  ***************************************************************************/
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 // ----------------------------------------------------------------------------
 // QT Includes
 
@@ -473,7 +477,7 @@ const TQDate MyMoneyQifProfile::date(const TQString& datein) const
       }
     }
     if(j == 13) {
-      tqWarning("Unknown month '%s'", scannedParts[d->m_partPos['m']].data());
+      tqWarning(TQString("Unknown month '%1'").arg(scannedParts[d->m_partPos['m']]));
       return TQDate();
     }
   }
@@ -569,8 +573,8 @@ const TQDate MyMoneyQifProfile::date(const TQString& datein) const
   for(i = 0; i < 2; ++i) {
     if(scannedDelim[i] != formatDelim[i]
     && scannedDelim[i] != TQChar('\'')) {
-      tqWarning("MyMoneyQifProfile::date(const TQString& datein) Invalid delimiter '%s' when '%s' was expected",
-        scannedDelim[i].latin1(), formatDelim[i].latin1());
+      tqWarning(TQString("MyMoneyQifProfile::date(const TQString& datein) Invalid delimiter '%1' when '%2' was expected").
+        arg(scannedDelim[i]).arg(formatDelim[i]));
       return TQDate();
     }
   }
@@ -654,7 +658,7 @@ const TQDate MyMoneyQifProfile::date(const TQString& datein) const
         break;
     }
     if(!msg.isEmpty()) {
-      tqWarning("MyMoneyQifProfile::date(const TQString& datein) %s",msg.latin1());
+      tqWarning(TQString("MyMoneyQifProfile::date(const TQString& datein) %1").arg(msg));
       return TQDate();
     }
   }
