@@ -21,6 +21,10 @@
  *                                                                         *
  ***************************************************************************/
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <iostream>
 
 // ----------------------------------------------------------------------------
@@ -332,7 +336,7 @@ void MyMoneyQifReader::slotImportFinished(void)
   if(!m_lineBuffer.isEmpty()) {
     m_qifLines << TQString::fromUtf8(m_lineBuffer.stripWhiteSpace());
   }
-  tqDebug("Read %d bytes", m_pos);
+  tqDebug("Read %ld bytes", m_pos);
   TQTimer::singleShot(0, this, TQT_SLOT(slotProcessData()));
 }
 
@@ -361,13 +365,13 @@ void MyMoneyQifReader::slotProcessData(void)
 
   m_qifProfile.setInputDateFormat(list.first());
 
-  tqDebug("Selected date format: '%s'", list.first().data());
+  tqDebug(TQString("Selected date format: '%1'").arg(list.first()));
 
   signalProgress(0, m_qifLines.count(), i18n("Importing QIF ..."));
   TQStringList::iterator it;
   for(it = m_qifLines.begin(); m_userAbort == false && it != m_qifLines.end(); ++it) {
     ++m_linenumber;
-    // tqDebug("Proc: '%s'", (*it).data());
+    // tqDebug(TQString("Proc: '%1'").arg(*it));
     if((*it).startsWith("!")) {
       processQifSpecial(*it);
       m_qifEntry.clear();
@@ -617,7 +621,7 @@ void MyMoneyQifReader::processQifSpecial(const TQString& _line)
       m_entryType = EntrySkip;
 
     } else {
-      tqWarning("Unknown export header '!Type:%s' in QIF file on line %d: Skipping section.", line.data(), m_linenumber);
+      tqWarning(TQString("Unknown export header '!Type:%1' in QIF file on line %2: Skipping section.").arg(line).arg(m_linenumber));
       m_entryType = EntrySkip;
     }
 
@@ -1013,7 +1017,7 @@ void MyMoneyQifReader::processTransactionEntry(void)
   h = MyMoneyTransaction::hash(m_qifEntry.join(";"));
 
   TQString hashBase;
-  hashBase.sprintf("%s-%07lx", m_qifProfile.date(extractLine('D')).toString(Qt::ISODate).data(), h);
+  hashBase.sprintf("%s-%07lx", m_qifProfile.date(extractLine('D')).toString(Qt::ISODate).latin1(), h);
   int idx = 1;
   TQString hash;
   for(;;) {
@@ -1168,7 +1172,7 @@ void MyMoneyQifReader::processTransactionEntry(void)
         }
 
       } catch (MyMoneyException *e) {
-        kdDebug(0) << "Line " << m_linenumber << ": Account with id " << accountId.data() << " not found" << endl;
+        kdDebug(0) << "Line " << m_linenumber << ": Account with id " << accountId << " not found" << endl;
         accountId = TQString();
         delete e;
       }
@@ -1227,7 +1231,7 @@ void MyMoneyQifReader::processTransactionEntry(void)
           }
 
         } catch (MyMoneyException *e) {
-          kdDebug(0) << "Line " << m_linenumber << ": Account with id " << accountId.data() << " not found" << endl;
+          kdDebug(0) << "Line " << m_linenumber << ": Account with id " << accountId << " not found" << endl;
           accountId = TQString();
           delete e;
         }
@@ -1323,7 +1327,7 @@ void MyMoneyQifReader::processInvestmentTransactionEntry(void)
   h = MyMoneyTransaction::hash(m_qifEntry.join(";"));
 
   TQString hashBase;
-  hashBase.sprintf("%s-%07lx", m_qifProfile.date(extractLine('D')).toString(Qt::ISODate).data(), h);
+  hashBase.sprintf("%s-%07lx", m_qifProfile.date(extractLine('D')).toString(Qt::ISODate).latin1(), h);
   int idx = 1;
   TQString hash;
   for(;;) {
@@ -1990,7 +1994,7 @@ TQString MyMoneyQifReader::processAccountEntry(bool resetAccountId)
   TQString tmp;
 
   account.setName(extractLine('N'));
-  // tqDebug("Process account '%s'", account.name().data());
+  // tqDebug(TQString("Process account '%1'").arg(account.name()));
 
   account.setDescription(extractLine('D'));
 
