@@ -15,6 +15,10 @@
  *                                                                         *
  ***************************************************************************/
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <typeinfo>
 
 // ----------------------------------------------------------------------------
@@ -349,7 +353,7 @@ int InvestTransactionEditor::editSplits(const TQString& categoryWidgetName, cons
 
     MyMoneyTransaction transaction;
     transaction.setCommodity(m_currency.id());
-    if(splits.count() == 0 && category->selectedItem()) {
+    if(splits.count() == 0 && !category->selectedItem().isEmpty()) {
       MyMoneySplit s;
       s.setAccountId(category->selectedItem());
       s.setShares(amount->value());
@@ -697,7 +701,6 @@ TQWidget* InvestTransactionEditor::firstWidget(void) const
 bool InvestTransactionEditor::isComplete(TQString& reason) const
 {
   reason = TQString();
-  // reason.clear();  // for TQt4
   return d->m_activity->isComplete(reason);
 }
 
