@@ -34,7 +34,7 @@ class InvestTransactionEditor : public TransactionEditor
 {
   friend class InvestTransactionEditorPrivate;
 
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   typedef enum {
