@@ -21,6 +21,10 @@
  *                                                                         *
  ***************************************************************************/
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 // ----------------------------------------------------------------------------
 // QT Includes
 
@@ -365,7 +369,7 @@ void KEquityPriceUpdateDlg::storePrices(void)
     ft.commit();
 
   } catch(MyMoneyException *e) {
-    tqDebug("Unable to add price information for %s", name.data());
+    tqDebug(TQString("Unable to add price information for %1").arg(name));
     delete e;
   }
 }
