@@ -18,6 +18,10 @@
  *                                                                         *
  ***************************************************************************/
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 // ----------------------------------------------------------------------------
 // QT Headers
 
@@ -108,7 +112,7 @@ void KImportDlg::slotBrowse()
 
   KFileDialog dialog(TDEGlobalSettings::documentPath(),
                      i18n("%1|Import files\n%2|All files (*.*)").arg(tmpprofile.filterFileType()).arg("*"),
-                     this, i18n("Import File..."), true);
+                     this, i18n("Import File...").utf8(), true);
   dialog.setMode(KFile::File | KFile::ExistingOnly);
 
   if(dialog.exec() == TQDialog::Accepted) {
