@@ -324,7 +324,7 @@ bool kMyMoneySplitTable::eventFilter(TQObject *o, TQEvent *e)
         // in case we have the 'enter moves focus between fields', we need to simulate
         // a TAB key when the object 'o' points to the category or memo field.
         if(KMyMoneyGlobalSettings::enterMovesBetweenFields()) {
-          if(TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(m_editCategory->lineEdit()) || TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(m_editMemo)) {
+          if(o == m_editCategory->lineEdit() || o == m_editMemo) {
             terminate = false;
             TQKeyEvent evt(e->type(),
                           Key_Tab, 0, k->state(), TQString(),
@@ -981,7 +981,7 @@ bool kMyMoneySplitTable::focusNextPrevChild(bool next)
       }
 
       if(w != currentWidget
-      && ((w->focusPolicy() & TQ_TabFocus) == TQ_TabFocus)
+      && ((w->focusPolicy() & TQWidget::TabFocus) == TQWidget::TabFocus)
       && w->isVisible() && w->isEnabled()) {
         w->setFocus();
         rc = true;
