@@ -50,7 +50,7 @@ class kMyMoneyLineEdit;
 
 class KSplitTransactionDlg : public KSplitTransactionDlgDecl
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
