@@ -40,7 +40,7 @@ class TQListViewItem;
 
 class MyMoneyQifProfileNameValidator : public TQValidator
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
@@ -53,7 +53,7 @@ public:
 
 class MyMoneyQifProfileEditor : public MyMoneyQifProfileEditorDecl
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
