@@ -91,7 +91,7 @@ namespace KMyMoneyPlugin { class ImporterPlugin; }
   */
 class KMyMoney2App : public TDEMainWindow, public DCOPObject
 {
-  Q_OBJECT
+  TQ_OBJECT
 //   
   K_DCOP
 
