@@ -33,7 +33,7 @@
 
 class TDEStartupSplash : public KSplashScreen
 {
-  Q_OBJECT
+  TQ_OBJECT
   
   public:
     TDEStartupSplash(const TQPixmap &pixmap, WFlags f = 0);
@@ -51,7 +51,7 @@ class TDEStartupSplash : public KSplashScreen
 // Simple class that just shows a picture
 class TDEStartupLogo : public TQObject
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   TDEStartupLogo();
