@@ -16,6 +16,10 @@
  *                                                                         *
  ***************************************************************************/
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 // ----------------------------------------------------------------------------
 // QT Includes
 
@@ -62,7 +66,7 @@ MyMoneyAccount::MyMoneyAccount(const TQDomElement& node) :
 
   setName(node.attribute("name"));
 
-  // tqDebug("Reading information for account %s", acc.name().data());
+  // tqDebug(TQString("Reading information for account %1").arg(acc.name()));
 
   setParentAccountId(TQStringEmpty(node.attribute("parentaccount")));
   setLastModified(stringToDate(TQStringEmpty(node.attribute("lastmodified"))));
@@ -93,7 +97,7 @@ MyMoneyAccount::MyMoneyAccount(const TQDomElement& node) :
   if(bOK) {
     setAccountType(static_cast<MyMoneyAccount::accountTypeE>(type));
   } else {
-    tqWarning("XMLREADER: Account %s had invalid or no account type information.", name().data());
+    tqWarning(TQString("XMLREADER: Account %1 had invalid or no account type information.").arg(name()));
   }
 
   if(node.hasAttribute("openingbalance")) {
@@ -105,7 +109,7 @@ MyMoneyAccount::MyMoneyAccount(const TQDomElement& node) :
   setDescription(node.attribute("description"));
 
   m_id = TQStringEmpty(node.attribute("id"));
-  // tqDebug("Account %s has id of %s, type of %d, parent is %s.", acc.name().data(), id.data(), type, acc.parentAccountId().data());
+  // tqDebug(TQString("Account %1 has id of %2, type of %3, parent is %4.").arg(acc.name()).arg(id).arg(type).arg(acc.parentAccountId()));
 
   //  Process any Sub-Account information found inside the account entry.
   m_accountList.clear();
@@ -301,7 +305,7 @@ const MyMoneyMoney MyMoneyAccountLoan::interestRate(const TQDate& date) const
 
   for(it = pairs().begin(); it != pairs().end(); ++it) {
     if(regExp.search(it.key()) > -1) {
-      if(qstrcmp(it.key(),key) <= 0)
+      if(it.key() <= key)
         val = *it;
       else
         break;
