@@ -132,7 +132,7 @@ class MyMoneyTransactionFilter;
   */
 class KMYMONEY_EXPORT MyMoneyFile : public TQObject
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
 
