@@ -17,6 +17,10 @@
  *                                                                         *
  ***************************************************************************/
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <typeinfo>
 #include "mymoneyseqaccessmgr.h"
 #include "../mymoneytransactionfilter.h"
@@ -870,7 +874,7 @@ const MyMoneyMoney MyMoneySeqAccessMgr::balance(const TQString& id, const TQDate
 {
   MyMoneyMoney result(0);
   MyMoneyAccount acc;
-  // if (date != TQDate()) tqDebug ("request balance for %s at %s", id.data(), date.toString(Qt::ISODate).latin1());
+  // if (date != TQDate()) tqDebug(TQString("request balance for %1 at %2").arg(id).arg(date.toString(Qt::ISODate)));
   if(!date.isValid() && account(id).accountType() != MyMoneyAccount::Stock) {
     if(m_accountList.find(id) != m_accountList.end())
       return m_accountList[id].balance();
@@ -1021,7 +1025,7 @@ void MyMoneySeqAccessMgr::loadAccounts(const TQMap<TQString, MyMoneyAccount>& ma
 
   int pos = lastId.find(TQRegExp("\\d+"), 0);
   if(pos != -1) {
-    m_nextAccountID = atol(lastId.mid(pos));
+    m_nextAccountID = lastId.mid(pos).toLong();
   }
 }
 
@@ -1044,7 +1048,7 @@ void MyMoneySeqAccessMgr::loadTransactions(const TQMap<TQString, MyMoneyTransact
 
   int pos = lastId.find(TQRegExp("\\d+"), 0);
   if(pos != -1) {
-    m_nextTransactionID = atol(lastId.mid(pos));
+    m_nextTransactionID = lastId.mid(pos).toLong();
   }
 }
 
@@ -1062,7 +1066,7 @@ void MyMoneySeqAccessMgr::loadInstitutions(const TQMap<TQString, MyMoneyInstitut
 
   int pos = lastId.find(TQRegExp("\\d+"), 0);
   if(pos != -1) {
-    m_nextInstitutionID = atol(lastId.mid(pos));
+    m_nextInstitutionID = lastId.mid(pos).toLong();
   }
 }
 
@@ -1083,7 +1087,7 @@ void MyMoneySeqAccessMgr::loadPayees(const TQMap<TQString, MyMoneyPayee>& map)
 
   int pos = lastId.find(TQRegExp("\\d+"), 0);
   if(pos != -1) {
-    m_nextPayeeID = atol(lastId.mid(pos));
+    m_nextPayeeID = lastId.mid(pos).toLong();
   }
 }
 
@@ -1101,7 +1105,7 @@ void MyMoneySeqAccessMgr::loadSecurities(const TQMap<TQString, MyMoneySecurity>&
 
   int pos = lastId.find(TQRegExp("\\d+"), 0);
   if(pos != -1) {
-    m_nextSecurityID = atol(lastId.mid(pos));
+    m_nextSecurityID = lastId.mid(pos).toLong();
   }
 }
 
@@ -1248,7 +1252,7 @@ const TQValueList<MyMoneySchedule> MyMoneySeqAccessMgr::scheduleList(
   // tqDebug("scheduleList()");
 
   for(pos = m_scheduleList.begin(); pos != m_scheduleList.end(); ++pos) {
-    // tqDebug("  '%s'", qPrintable((*pos).id()));
+    // tqDebug(TQString("  '%1'").arg(qPrintable((*pos).id())));
 
     if(type != MyMoneySchedule::TYPE_ANY) {
       if(type != (*pos).type()) {
@@ -1305,7 +1309,7 @@ const TQValueList<MyMoneySchedule> MyMoneySeqAccessMgr::scheduleList(
         continue;
     }
 
-    // tqDebug("Adding '%s'", (*pos).name().latin1());
+    // tqDebug(TQString("Adding '%1'").arg((*pos).name()));
     list << *pos;
   }
   return list;
@@ -1325,7 +1329,7 @@ void MyMoneySeqAccessMgr::loadSchedules(const TQMap<TQString, MyMoneySchedule>&
 
   int pos = lastId.find(TQRegExp("\\d+"), 0);
   if(pos != -1) {
-    m_nextScheduleID = atol(lastId.mid(pos));
+    m_nextScheduleID = lastId.mid(pos).toLong();
   }
 }
 
@@ -1374,7 +1378,7 @@ const TQValueList<MyMoneySchedule> MyMoneySeqAccessMgr::scheduleListEx(int sched
         continue;
     }
 
-//    tqDebug("\tAdding '%s'", (*pos).name().latin1());
+//    tqDebug(TQString("\tAdding '%1'").arg((*pos).name()));
     list << *pos;
   }
 
@@ -1527,7 +1531,7 @@ void MyMoneySeqAccessMgr::loadReports(const TQMap<TQString, MyMoneyReport>& map)
 
   int pos = lastId.find(TQRegExp("\\d+"), 0);
   if(pos != -1) {
-    m_nextReportID = atol(lastId.mid(pos));
+    m_nextReportID = lastId.mid(pos).toLong();
   }
 }
 
@@ -1601,7 +1605,7 @@ void MyMoneySeqAccessMgr::loadBudgets(const TQMap<TQString, MyMoneyBudget>& map)
 
   int pos = lastId.find(TQRegExp("\\d+"), 0);
   if(pos != -1) {
-    m_nextBudgetID = atol(lastId.mid(pos));
+    m_nextBudgetID = lastId.mid(pos).toLong();
   }
 }
 
@@ -1940,5 +1944,3 @@ void MyMoneySeqAccessMgr::removeReferences(const TQString& id)
 #undef TRY
 #undef CATCH
 #undef PASS
-
-// vim:cin:si:ai:et:ts=2:sw=2:
