@@ -20,8 +20,8 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef MYMONEYSETQACCESSMGR_H
-#define MYMONEYSETQACCESSMGR_H
+#ifndef MYMONEYSEQACCESSMGR_H
+#define MYMONEYSEQACCESSMGR_H
 
 // ----------------------------------------------------------------------------
 // QT Includes
@@ -100,7 +100,7 @@ public:
   /**
     * This method is used to get a SQL reader for subsequent database access
     */
-  KSharedPtr <MyMoneyStorageSql> connectToDatabase (const KURL& url);
+  TDESharedPtr <MyMoneyStorageSql> connectToDatabase (const KURL& url);
    /**
    * This method is used when a database file is open, and the data is to
    * be saved in a different file or format. It will ensure that all data
