@@ -17,7 +17,9 @@
  *                                                                         *
  ***************************************************************************/
 
-#include "config.h"
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
 
 // ----------------------------------------------------------------------------
 // QT Includes
@@ -30,7 +32,6 @@
 // ----------------------------------------------------------------------------
 // KDE Includes
 
-#include "kdecompat.h"
 #include <tdelocale.h>
 #include <kdebug.h>
 
