@@ -40,7 +40,7 @@ namespace KMyMoneyPlugin {
   * ViewInterface.
   */
 class KMMViewInterface : public ViewInterface {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
