@@ -42,7 +42,7 @@ class KOnlineBankingStatus;
 */
 class OfxImporterPlugin : public KMyMoneyPlugin::Plugin, public KMyMoneyPlugin::ImporterPlugin, public KMyMoneyPlugin::OnlinePlugin
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
     OfxImporterPlugin(TQObject *parent = 0, const char *name = 0, const TQStringList& = TQStringList());
