@@ -17,6 +17,10 @@
  *                                                                         *
  ***************************************************************************/
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 // ----------------------------------------------------------------------------
 // QT Includes
 #include <tqlayout.h>
@@ -72,7 +76,7 @@ Debug::Debug( const TQString& _name ): m_methodName( _name ), m_enabled( m_sEnab
 
   if (m_enabled)
   {
-    tqDebug( "%s%s(): ENTER", m_sTabs.latin1(), m_methodName.latin1() );
+    tqDebug(TQString("%1%2(): ENTER").arg(m_sTabs).arg(m_methodName));
     m_sTabs.append("--");
   }
 }
@@ -82,7 +86,7 @@ Debug::~Debug()
   if ( m_enabled )
   {
     m_sTabs.remove(0,2);
-    tqDebug( "%s%s(): EXIT", m_sTabs.latin1(), m_methodName.latin1() );
+    tqDebug(TQString("%1%2(): EXIT").arg(m_sTabs).arg(m_methodName));
 
     if (m_methodName == m_sEnableKey)
       m_enabled = false;
@@ -92,7 +96,7 @@ Debug::~Debug()
 void Debug::output( const TQString& _text )
 {
   if ( m_enabled )
-    tqDebug( "%s%s(): %s", m_sTabs.latin1(), m_methodName.latin1(), _text.latin1() );
+    tqDebug(TQString("%1%2(): %3").arg(m_sTabs).arg(m_methodName).arg(_text));
 }
 
 PivotTable::PivotTable( const MyMoneyReport& _config_f ):
@@ -190,7 +194,7 @@ void PivotTable::init(void)
   try {
     transactions = file->transactionList(m_config_f);
   } catch(MyMoneyException *e) {
-    tqDebug("ERR: %s thrown in %s(%ld)", e->what().data(), e->file().data(), e->line());
+    tqDebug(TQString("ERR: %1 thrown in %2(%s)").arg(e->what()).arg(e->file()).arg(e->line()));
     throw e;
   }
   DEBUG_OUTPUT(TQString("Found %1 matching transactions").arg(transactions.count()));
@@ -1632,7 +1636,7 @@ TQString PivotTable::renderHTML( void ) const
 
       for(unsigned i = 0; i < m_rowTypeList.size(); ++i) {
         result += TQString("<td%2>%1</td>")
-            .arg(i18n( m_columnTypeHeaderList[i] ))
+            .arg(i18n(m_columnTypeHeaderList[i].utf8()))
             .arg(i == 0 ? lb : TQString() );
       }
       column++;
@@ -1640,7 +1644,7 @@ TQString PivotTable::renderHTML( void ) const
     if ( m_config_f.isShowingRowTotals() ) {
       for(unsigned i = 0; i < m_rowTypeList.size(); ++i) {
         result += TQString("<td%2>%1</td>")
-            .arg(i18n( m_columnTypeHeaderList[i] ))
+            .arg(i18n(m_columnTypeHeaderList[i].utf8()))
             .arg(i == 0 ? leftborder : TQString() );
       }
     }
@@ -2616,4 +2620,3 @@ void PivotTable::includeInvestmentSubAccounts()
 }
 
 } // namespace
-// vim:cin:si:ai:et:ts=2:sw=2:
