@@ -15,6 +15,10 @@
  *                                                                         *
  ***************************************************************************/
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <typeinfo>
 
 // ----------------------------------------------------------------------------
@@ -27,7 +31,6 @@
 // ----------------------------------------------------------------------------
 // KDE Includes
 
-#include "kdecompat.h"
 #include <tdelocale.h>
 #include <kcombobox.h>
 #include <kpushbutton.h>
@@ -564,9 +567,9 @@ void TDEGlobalLedgerView::loadView(void)
       paymentAmount[it_b.key()] = MyMoneyMoney();
     }
 
-    tracer.printf("total balance of %s = %s", m_account.name().data(), actBalance[m_account.id()].formatMoney("", 2).data());
-    tracer.printf("future balance of %s = %s", m_account.name().data(), futureBalance[m_account.id()].formatMoney("", 2).data());
-    tracer.printf("cleared balance of %s = %s", m_account.name().data(), clearedBalance[m_account.id()].formatMoney("", 2).data());
+    tracer.printf("total balance of %s = %s", m_account.name().local8Bit().data(), actBalance[m_account.id()].formatMoney("", 2).local8Bit().data());
+    tracer.printf("future balance of %s = %s", m_account.name().local8Bit().data(), futureBalance[m_account.id()].formatMoney("", 2).local8Bit().data());
+    tracer.printf("cleared balance of %s = %s", m_account.name().local8Bit().data(), clearedBalance[m_account.id()].formatMoney("", 2).local8Bit().data());
 
     KMyMoneyRegister::RegisterItem* p = m_register->lastItem();
     focusItem = 0;
@@ -616,11 +619,11 @@ void TDEGlobalLedgerView::loadView(void)
 
         if(!t->isScheduled()) {
           if(split.reconcileFlag() == MyMoneySplit::NotReconciled) {
-            tracer.printf("Reducing cleared balance by %s because %s/%s(%s) is not reconciled", (split.shares() * factor).formatMoney("", 2).data(), t->transaction().id().data(), split.id().data(), t->transaction().postDate().toString(Qt::ISODate).data());
+            tracer.printf("Reducing cleared balance by %s because %s/%s(%s) is not reconciled", (split.shares() * factor).formatMoney("", 2).local8Bit().data(), t->transaction().id().local8Bit().data(), split.id().local8Bit().data(), t->transaction().postDate().toString(Qt::ISODate).local8Bit().data());
             clearedBalance[split.accountId()] -= split.shares() * factor;
           }
           if(isReconciliationAccount() && t->transaction().postDate() > reconciliationDate && split.reconcileFlag() == MyMoneySplit::Cleared) {
-            tracer.printf("Reducing cleared balance by %s because we are in reconciliation, %s/%s(%s)'s date is after or on reconciliation date (%s) and is cleared", (split.shares() * factor).formatMoney("", 2).data(), t->transaction().id().data(), split.id().data(), t->transaction().postDate().toString(Qt::ISODate).data(), reconciliationDate.toString(Qt::ISODate).data());
+            tracer.printf("Reducing cleared balance by %s because we are in reconciliation, %s/%s(%s)'s date is after or on reconciliation date (%s) and is cleared", (split.shares() * factor).formatMoney("", 2).local8Bit().data(), t->transaction().id().local8Bit().data(), split.id().local8Bit().data(), t->transaction().postDate().toString(Qt::ISODate).local8Bit().data(), reconciliationDate.toString(Qt::ISODate).local8Bit().data());
 
             clearedBalance[split.accountId()] -= split.shares() * factor;
           }
@@ -635,7 +638,7 @@ void TDEGlobalLedgerView::loadView(void)
           }
 
           if(t->transaction().postDate() > TQDate::currentDate()) {
-            tracer.printf("Reducing actual balance by %s because %s/%s(%s) is in the future", (split.shares() * factor).formatMoney("", 2).data(), t->transaction().id().data(), split.id().data(), t->transaction().postDate().toString(Qt::ISODate).data());
+            tracer.printf("Reducing actual balance by %s because %s/%s(%s) is in the future", (split.shares() * factor).formatMoney("", 2).local8Bit().data(), t->transaction().id().local8Bit().data(), split.id().local8Bit().data(), t->transaction().postDate().toString(Qt::ISODate).local8Bit().data());
             actBalance[split.accountId()] -= split.shares() * factor;
           }
         }
@@ -644,9 +647,9 @@ void TDEGlobalLedgerView::loadView(void)
       p = p->prevItem();
     }
 
-    tracer.printf("total balance of %s = %s", m_account.name().data(), actBalance[m_account.id()].formatMoney("", 2).data());
-    tracer.printf("future balance of %s = %s", m_account.name().data(), futureBalance[m_account.id()].formatMoney("", 2).data());
-    tracer.printf("cleared balance of %s = %s", m_account.name().data(), clearedBalance[m_account.id()].formatMoney("", 2).data());
+    tracer.printf("total balance of %s = %s", m_account.name().local8Bit().data(), actBalance[m_account.id()].formatMoney("", 2).local8Bit().data());
+    tracer.printf("future balance of %s = %s", m_account.name().local8Bit().data(), futureBalance[m_account.id()].formatMoney("", 2).local8Bit().data());
+    tracer.printf("cleared balance of %s = %s", m_account.name().local8Bit().data(), clearedBalance[m_account.id()].formatMoney("", 2).local8Bit().data());
 
     // update statement information
     if(statement) {
@@ -847,7 +850,7 @@ void TDEGlobalLedgerView::loadAccounts(void)
     try {
       d->m_precision = MyMoneyMoney::denomToPrec(m_account.fraction());
     } catch(MyMoneyException *e) {
-      tqDebug("Security %s for account %s not found", m_account.currencyId().data(), m_account.name().data());
+      tqDebug(TQString("Security %1 for account %2 not found").arg(m_account.currencyId()).arg(m_account.name()));
       delete e;
       d->m_precision = 2;
     }
@@ -956,7 +959,7 @@ bool TDEGlobalLedgerView::slotSelectAccount(const TQString& id, const TQString&
         m_newAccountLoaded = true;
         slotLoadView();
       } catch(MyMoneyException* e) {
-        tqDebug("Unable to retrieve account %s", id.data());
+        tqDebug(TQString("Unable to retrieve account %1").arg(id));
         delete e;
         rc = false;
       }
@@ -1214,10 +1217,10 @@ bool TDEGlobalLedgerView::focusNextPrevChild(bool next)
 
     w = tqApp->focusWidget();
     while(w && m_tabOrderWidgets.find(w) == -1) {
-      // tqDebug("'%s' not in list, use parent", w->className());
+      // tqDebug(TQString("'%1' not in list, use parent").arg(w->className()));
       w = w->parentWidget();
     }
-    // if(w) tqDebug("tab order is at '%s'", w->className());
+    // if(w) tqDebug(TQString("tab order is at '%1'").arg(w->className()));
     currentWidget = m_tabOrderWidgets.current();
     w = next ? m_tabOrderWidgets.next() : m_tabOrderWidgets.prev();
 
@@ -1227,9 +1230,9 @@ bool TDEGlobalLedgerView::focusNextPrevChild(bool next)
       }
 
       if(w != currentWidget
-      && ((w->focusPolicy() & TQ_TabFocus) == TQ_TabFocus)
+      && ((w->focusPolicy() & TQWidget::TabFocus) == TQWidget::TabFocus)
       && w->isVisible() && w->isEnabled()) {
-        // tqDebug("Selecting '%s' as focus", w->className());
+        // tqDebug(TQString("Selecting '%1' as focus").arg(w->className()));
         w->setFocus();
         rc = true;
         break;
@@ -1270,15 +1273,15 @@ bool TDEGlobalLedgerView::eventFilter(TQObject* o, TQEvent* e)
   if(e->type() == TQEvent::KeyPress) {
     TQKeyEvent *k = TQT_TQKEYEVENT(e);
     if(m_inEditMode) {
-      // tqDebug("object = %s, key = %d", o->className(), k->key());
-      if(TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(m_register)) {
+      // tqDebug(TQString("object = %1, key = %2").arg(o->className()).arg(k->key()));
+      if(o == m_register) {
         // we hide all key press events from the register
         // while editing a transaction
         rc = true;
       }
     } else {
-      // tqDebug("object = %s, key = %d", o->className(), k->key());
-      if(TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(m_register)) {
+      // tqDebug(TQString("object = %1, key = %2").arg(o->className()).arg(k->key()));
+      if(o == m_register) {
         if((k->state() & TQt::KeyButtonMask) == 0) {
           switch(k->key()) {
             case TQt::Key_Return:
@@ -1333,7 +1336,7 @@ void TDEGlobalLedgerView::slotSortOptions(void)
         MyMoneyFile::instance()->modifyAccount(m_account);
         ft.commit();
       } catch(MyMoneyException* e) {
-        tqDebug("Unable to update sort order for account '%s': %s", m_account.name().latin1(), e->what().latin1());
+        tqDebug(TQString("Unable to update sort order for account '%1': %2").arg(m_account.name()).arg(e->what()));
         delete e;
       }
     }
