@@ -41,7 +41,7 @@
   */
 class KInstitutionsView : public KInstitutionsViewDecl
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 private:
 
