@@ -40,24 +40,24 @@
 // ----------------------------------------------------------------------------
 // KDE Includes
 
-#include "kdecompat.h"
+#include <tdeversion.h>
 
-#include <kfiledialog.h>
-#include <kglobal.h>
+#include <tdefiledialog.h>
+#include <tdeglobal.h>
 #include <kstandarddirs.h>
 #include <kicontheme.h>
 #include <kiconloader.h>
 
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 #include <kurl.h>
-#include <kio/netaccess.h>
-#include <ktempfile.h>
+#include <tdeio/netaccess.h>
+#include <tdetempfile.h>
 #include <ksavefile.h>
 #include <kfilterdev.h>
 #include <kfilterbase.h>
-#include <kfileitem.h>
+#include <tdefileitem.h>
 #include <kpushbutton.h>
-#include <kapplication.h>
+#include <tdeapplication.h>
 #include <kdebug.h>
 
 // ----------------------------------------------------------------------------
@@ -210,7 +210,7 @@ KMyMoneyView::KMyMoneyView(TQWidget *parent, const char *name)
   // Page 6
   m_ledgerViewFrame = addVBoxPage( i18n("Ledgers"), i18n("Ledgers"),
     DesktopIcon("ledger", iconSize));
-  m_ledgerView = new KGlobalLedgerView(m_ledgerViewFrame, "GlobalLedgerView");
+  m_ledgerView = new TDEGlobalLedgerView(m_ledgerViewFrame, "GlobalLedgerView");
   connect(m_ledgerView, TQT_SIGNAL(accountSelected(const MyMoneyObject&)), kmymoney2, TQT_SLOT(slotSelectAccount(const MyMoneyObject&)));
   connect(m_ledgerView, TQT_SIGNAL(openContextMenu()), kmymoney2, TQT_SLOT(slotShowTransactionContextMenu()));
   connect(m_ledgerView, TQT_SIGNAL(transactionsSelected(const KMyMoneyRegister::SelectedTransactions&)), kmymoney2, TQT_SLOT(slotSelectTransactions(const KMyMoneyRegister::SelectedTransactions&)));
@@ -254,7 +254,7 @@ KMyMoneyView::KMyMoneyView(TQWidget *parent, const char *name)
   m_forecastView = new KForecastView(m_forecastViewFrame, "ForecastView");
 
   // get rid of the title text
-  TQWidget* widget = dynamic_cast<TQWidget*>(child("KJanusWidgetTitleLabel", TQLABEL_OBJECT_NAME_STRING));
+  TQWidget* widget = dynamic_cast<TQWidget*>(child("KJanusWidgetTitleLabel", "TQLabel"));
   if(widget)
     widget->hide();
 
@@ -483,11 +483,11 @@ void KMyMoneyView::slotLedgerSelected(const TQString& _accId, const TQString& tr
     case MyMoneyAccount::CertificateDep:
     case MyMoneyAccount::MoneyMarket:
     case MyMoneyAccount::Currency:
-      qDebug("No ledger view available for account type %d", acc.accountType());
+      tqDebug("No ledger view available for account type %d", acc.accountType());
       break;
 
     default:
-      qDebug("Unknown account type %d in KMyMoneyView::slotLedgerSelected", acc.accountType());
+      tqDebug("Unknown account type %d in KMyMoneyView::slotLedgerSelected", acc.accountType());
       break;
   }
 }
@@ -559,7 +559,7 @@ bool KMyMoneyView::readFile(const KURL& url)
 #else
   if(url.isMalformed()) {
 #endif
-    qDebug("Invalid URL '%s'", url.url().latin1());
+    tqDebug(TQString("Invalid URL '%1'").arg(url.url()));
     return false;
   }
 
@@ -581,10 +581,10 @@ bool KMyMoneyView::readFile(const KURL& url)
     filename = url.path();
 
   } else {
-    if(!KIO::NetAccess::download(url, filename, NULL)) {
+    if(!TDEIO::NetAccess::download(url, filename, NULL)) {
       KMessageBox::detailedError(this,
              i18n("Error while loading file '%1'!").arg(url.url()),
-             KIO::NetAccess::lastErrorString(),
+             TDEIO::NetAccess::lastErrorString(),
              i18n("File access error"));
       return false;
     }
@@ -771,7 +771,7 @@ bool KMyMoneyView::readFile(const KURL& url)
   // if a temporary file was constructed by NetAccess::download,
   // then it will be removed with the next call. Otherwise, it
   // stays untouched on the local filesystem
-  KIO::NetAccess::removeTempFile(filename);
+  TDEIO::NetAccess::removeTempFile(filename);
   return initializeStorage();
 }
 
@@ -796,7 +796,7 @@ bool KMyMoneyView::openDatabase (const KURL& url) {
     pDBMgr = new MyMoneyDatabaseMgr;
     pStorage = dynamic_cast<IMyMoneySerialize*> (pDBMgr);
   }
-  KSharedPtr <MyMoneyStorageSql> reader = pStorage->connectToDatabase (url);
+  TDESharedPtr <MyMoneyStorageSql> reader = pStorage->connectToDatabase (url);
   KURL dbURL (url);
   bool retry = true;
   while (retry) {
@@ -890,7 +890,7 @@ bool KMyMoneyView::initializeStorage()
     selectBaseCurrency();
   }
 
-  KConfig *config = KGlobal::config();
+  TDEConfig *config = TDEGlobal::config();
   int page;
   config->setGroup("General Options");
   if(KMyMoneyGlobalSettings::startLastViewSelected() != 0) {
@@ -911,7 +911,7 @@ bool KMyMoneyView::initializeStorage()
       // Check if we have to modify the file before we allow to work with it
       IMyMoneyStorage* s = MyMoneyFile::instance()->storage();
       while (s->fileFixVersion() < s->currentFixVersion()) {
-        qDebug("%s", (TQString("testing fileFixVersion %1 < %2").arg(s->fileFixVersion()).arg(s->currentFixVersion())).data());
+        tqDebug(TQString("testing fileFixVersion %1 < %2").arg(s->fileFixVersion()).arg(s->currentFixVersion()));
         switch (s->fileFixVersion()) {
           case 0:
             fixFile_0();
@@ -941,7 +941,7 @@ bool KMyMoneyView::initializeStorage()
       return false;
     }
   } else {
-    qDebug("Skipping automatic transaction fix!");
+    tqDebug("Skipping automatic transaction fix!");
   }
   MyMoneyFile::instance()->blockSignals(blocked);
 
@@ -1150,11 +1150,11 @@ bool KMyMoneyView::saveFile(const KURL& url, const TQString& keyList)
           throw new MYMONEYEXCEPTION(i18n("Unable to write changes to '%1'").arg(filename));
         }
       }
-      chown(filename, static_cast<uid_t>(-1), gid);
+      chown(filename.local8Bit(), static_cast<uid_t>(-1), gid);
     } else {
       KTempFile tmpfile;
       saveToLocalFile(tmpfile.file(), pWriter, plaintext, keyList);
-      if(!KIO::NetAccess::upload(tmpfile.name(), url, NULL))
+      if(!TDEIO::NetAccess::upload(tmpfile.name(), url, NULL))
         throw new MYMONEYEXCEPTION(i18n("Unable to upload to '%1'").arg(url.url()));
       tmpfile.unlink();
     }
@@ -1308,7 +1308,7 @@ void KMyMoneyView::selectBaseCurrency(void)
           file->modifyAccount(*it);
           ft.commit();
         } catch(MyMoneyException *e) {
-          qDebug("Unable to setup base currency in account %s (%s): %s", (*it).name().latin1(), (*it).id().data(), e->what().latin1());
+          tqDebug(TQString("Unable to setup base currency in account %1 (%2): %3").arg((*it).name()).arg((*it).id()).arg(e->what()));
           delete e;
         }
       }
@@ -1336,7 +1336,7 @@ void KMyMoneyView::loadDefaultCurrency(const MyMoneySecurity& currency, const bo
       }
       ft.commit();
     } catch (MyMoneyException* e) {
-      qDebug("Error %s loading default currency", e->what().data());
+      tqDebug(TQString("Error %1 loading default currency").arg(e->what()));
       delete e;
     }
   }
@@ -1536,7 +1536,7 @@ void KMyMoneyView::loadAncientCurrency(const TQString& id, const TQString& name,
       }
       ft.commit();
     } catch(MyMoneyException *e) {
-      qDebug("Error loading currency: %s", e->what().data());
+      tqDebug(TQString("Error loading currency: %1").arg(e->what()));
       delete e;
     }
   }
@@ -1630,7 +1630,7 @@ void KMyMoneyView::progressCallback(int current, int total, const TQString& msg)
 
 void KMyMoneyView::slotRememberPage(TQWidget* w)
 {
-  KConfig *config = KGlobal::config();
+  TDEConfig *config = TDEGlobal::config();
   config->setGroup("Last Use Settings");
   config->writeEntry("LastViewSelected", pageIndex(w));
   config->sync();
@@ -1683,7 +1683,7 @@ void KMyMoneyView::fixFile_2(void)
       }
     }
   }
-  qDebug("%d transactions fixed in fixFile_2", count);
+  tqDebug("%d transactions fixed in fixFile_2", count);
 }
 
 void KMyMoneyView::fixFile_1(void)
@@ -1866,7 +1866,7 @@ void KMyMoneyView::fixSchedule_0(MyMoneySchedule sched)
       MyMoneyFile::instance()->modifySchedule(sched);
     }
   } catch(MyMoneyException *e) {
-    qWarning("Unable to update broken schedule: %s", e->what().latin1());
+    tqWarning(TQString("Unable to update broken schedule: %1").arg(e->what()));
     delete e;
   }
 }
@@ -2082,7 +2082,7 @@ void KMyMoneyView::fixTransactions_0(void)
         file->modifyTransaction(*it_t);
       }
       splits = (*it_t).splits();    // update local copy
-      qDebug("Fixed credit card assignment in %s", (*it_t).id().data());
+      tqDebug(TQString("Fixed credit card assignment in %1").arg((*it_t).id()));
     }
 #endif
 
@@ -2104,7 +2104,7 @@ void KMyMoneyView::fixTransactions_0(void)
           (*it_s).setAction(MyMoneySplit::ActionInterest);
           (*it_t).modifySplit(*it_s);
           file->modifyTransaction(*it_t);
-          qDebug("Fixed interest action in %s", (*it_t).id().data());
+          tqDebug(TQString("Fixed interest action in %1").arg((*it_t).id()));
         }
       // if it does not reference an interest account, it must not be
       // of type ActionInterest
@@ -2114,7 +2114,7 @@ void KMyMoneyView::fixTransactions_0(void)
           (*it_s).setAction(defaultAction);
           (*it_t).modifySplit(*it_s);
           file->modifyTransaction(*it_t);
-          qDebug("Fixed interest action in %s", (*it_t).id().data());
+          tqDebug(TQString("Fixed interest action in %1").arg((*it_t).id()));
         }
       }
 
@@ -2134,14 +2134,14 @@ void KMyMoneyView::fixTransactions_0(void)
         try {
           int fract = splitAccount.fraction();
           if((*it_s).shares() != (*it_s).shares().convert(fract)) {
-            qDebug("adjusting fraction in %s,%s", (*it_t).id().data(), (*it_s).id().data());
+            tqDebug(TQString("adjusting fraction in %1,%2").arg((*it_t).id()).arg((*it_s).id()));
             (*it_s).setShares((*it_s).shares().convert(fract));
             (*it_s).setValue((*it_s).value().convert(fract));
             (*it_t).modifySplit(*it_s);
             file->modifyTransaction(*it_t);
           }
         } catch(MyMoneyException* e) {
-          qDebug("Missing security '%s', split not altered", splitAccount.currencyId().data());
+          tqDebug(TQString("Missing security '%1', split not altered").arg(splitAccount.currencyId()));
           delete e;
         }
       }
@@ -2164,7 +2164,7 @@ void KMyMoneyView::fixTransactions_0(void)
 
 void KMyMoneyView::fixDuplicateAccounts_0(MyMoneyTransaction& t)
 {
-  qDebug("Duplicate account in transaction %s", t.id().data());
+  tqDebug(TQString("Duplicate account in transaction %1").arg(t.id()));
 }
 
 void KMyMoneyView::slotPrintView(void)
