@@ -20,6 +20,10 @@
  *                                                                         *
  ***************************************************************************/
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 // ----------------------------------------------------------------------------
 // QT Includes
 
@@ -484,7 +488,7 @@ void KScheduledView::slotSetSelectedItem(TQListViewItem* item)
       emit scheduleSelected(schedule);
       m_selectedSchedule = schedItem->scheduleId();
     } catch(MyMoneyException* e) {
-      tqDebug("KScheduledView::slotSetSelectedItem: %s", e->what().data());
+      tqDebug(TQString("KScheduledView::slotSetSelectedItem: %1").arg(e->what()));
       delete e;
     }
   }
