@@ -15,6 +15,10 @@
  *                                                                         *
  ***************************************************************************/
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 // ----------------------------------------------------------------------------
 // QT Includes
 
@@ -184,7 +188,7 @@ void KAccountTemplateSelector::slotLoadTemplateList(void)
   TQStringList::iterator it;
   for(it = d->dirlist.begin(); it != d->dirlist.end(); ++it) {
     TQDir dir(*it);
-    // tqDebug("Reading dir '%s' with %d entries", (*it).data(), dir.count());
+    // tqDebug(TQSttring("Reading dir '%1' with %2 entries").arg(*it).arg(dir.count()));
     dirs = dir.entryList("*", TQDir::Dirs);
     TQStringList::iterator it_d;
     for(it_d= dirs.begin(); it_d != dirs.end(); ++it_d) {
@@ -214,7 +218,7 @@ void KAccountTemplateSelector::slotLoadTemplateList(void)
         TQString country = TDEGlobal::locale()->twoAlphaToCountryName((*it_d).upper());
         d->countries[country] = *it_d;
       } else {
-        tqDebug("'%s/%s' not scanned", (*it).data(), (*it_d).data());
+        tqDebug(TQString("'%1/%2' not scanned").arg(*it).arg(*it_d));
       }
     }
   }
