@@ -38,7 +38,7 @@ class KMyMoneyAccountTreeBudgetItem;
 
 class KMyMoneyAccountTreeBudget : public KMyMoneyAccountTreeBase
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   KMyMoneyAccountTreeBudget(TQWidget* parent = 0, const char *name = 0);
