@@ -50,7 +50,7 @@ class kMyMoneyLineEdit;
   */
 class KMyMoneyCombo : public KComboBox
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   KMyMoneyCombo(TQWidget *w = 0, const char *name=0);
@@ -227,7 +227,7 @@ private:
   */
 class KMyMoneyReconcileCombo : public KMyMoneyCombo
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   KMyMoneyReconcileCombo(TQWidget *w = 0, const char *name=0);
@@ -249,7 +249,7 @@ protected slots:
   */
 class KMyMoneyComboAction : public KMyMoneyCombo
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   KMyMoneyComboAction(TQWidget *w = 0, const char *name=0);
@@ -272,7 +272,7 @@ signals:
   */
 class KMyMoneyCashFlowCombo : public KMyMoneyCombo
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   /**
@@ -302,7 +302,7 @@ private:
   */
 class KMyMoneyActivityCombo : public KMyMoneyCombo
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   /**
@@ -342,7 +342,7 @@ private:
   */
 class KMyMoneyPayeeCombo : public KMyMoneyCombo
 {
-   Q_OBJECT
+   TQ_OBJECT
   
 public:
   KMyMoneyPayeeCombo(TQWidget* parent = 0, const char* name = 0);
@@ -352,7 +352,7 @@ public:
 
 class KMyMoneyGeneralCombo : public KComboBox
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   KMyMoneyGeneralCombo(TQWidget* parent = 0, const char* name = 0);
@@ -395,7 +395,7 @@ private:
  */
 class KMyMoneyPeriodCombo : public KMyMoneyGeneralCombo
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   KMyMoneyPeriodCombo(TQWidget* parent = 0, const char* name = 0);
@@ -428,7 +428,7 @@ public:
  */
 class KMyMoneyOccurenceCombo : public KMyMoneyGeneralCombo
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   KMyMoneyOccurenceCombo(TQWidget* parent = 0, const char* name = 0);
@@ -443,7 +443,7 @@ public:
  */
 class KMyMoneyOccurencePeriodCombo : public KMyMoneyOccurenceCombo
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   KMyMoneyOccurencePeriodCombo(TQWidget* parent = 0, const char* name = 0);
@@ -455,7 +455,7 @@ public:
  */
 class KMyMoneyFrequencyCombo : public KMyMoneyOccurenceCombo
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   KMyMoneyFrequencyCombo(TQWidget* parent = 0, const char* name = 0);
