@@ -17,7 +17,7 @@
 #ifndef KMYMONEYEDIT_H
 #define KMYMONEYEDIT_H
 
-#include "kdecompat.h"
+#include <tdeversion.h>
 
 // ----------------------------------------------------------------------------
 // QT Includes
@@ -55,7 +55,7 @@ class kMyMoneyCalculator;
   */
 class kMyMoneyMoneyValidator : public TQDoubleValidator
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
@@ -91,7 +91,7 @@ public:
   */
 class kMyMoneyEdit : public TQHBox
 {
-  Q_OBJECT
+  TQ_OBJECT
   
   TQ_PROPERTY(bool calculatorButtonVisibility READ isCalculatorButtonVisible WRITE setCalculatorButtonVisible);
   TQ_PROPERTY(bool resetButtonVisibility READ isResetButtonVisible WRITE setResetButtonVisible);
