@@ -44,7 +44,7 @@
   */
 class kMyMoneyLineEdit : public KLineEdit
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   /**
