@@ -15,6 +15,10 @@
  *                                                                         *
  ***************************************************************************/
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <locale.h>
 
 // ----------------------------------------------------------------------------
@@ -1689,3 +1693,4 @@ void AccountSummaryPage::enterPage(void)
 }
 
 #include "knewaccountwizard.moc"
+#include "knewaccountwizard_p.moc"
