@@ -1,4 +1,4 @@
-/* -*- Mode: C++ -*-
+/*
    KDChart - a multi-platform charting engine
    */
 
@@ -27,6 +27,10 @@
  **
  **********************************************************************/
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "KDChartPropertySet.h"
 #include "KDChartParams.h"
 #include <KDXMLTools.h>
